poets.shape package
===================

Submodules
----------

poets.shape.shapes module
-------------------------

.. automodule:: poets.shape.shapes
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: poets.shape
    :members:
    :undoc-members:
    :show-inheritance:
